@@ -1,10 +1,14 @@
+import time
 import imp
-from django.core.management.base import BaseCommand, CommandError
+
+from django.core.management.base import BaseCommand
+
 from json_loader import load_json
 
+
 class Command(BaseCommand):
     def handle(self, *app_labels, **options):
-        from django.db.models import get_app, get_apps, get_models
+        from django.db.models import get_app, get_apps
 
         exclude = options.get('exclude', [])
 
@@ -26,4 +30,7 @@ class Command(BaseCommand):
                 generator = imp.load_module(name + '.generator', *params)
 
                 print "Generating items for %s." % name.title()
+                start = time.time()
                 load_json(generator.generate())
+                now = time.time()
+                print "Generation completed in %s seconds" % (now - start)
